/*
 * Fabric3
 * Copyright (c) 2009-2011 Metaform Systems
 *
 * Fabric3 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version, with the
 * following exception:
 *
 * Linking this software statically or dynamically with other
 * modules is making a combined work based on this software.
 * Thus, the terms and conditions of the GNU General Public
 * License cover the whole combination.
 *
 * As a special exception, the copyright holders of this software
 * give you permission to link this software with independent
 * modules to produce an executable, regardless of the license
 * terms of these independent modules, and to copy and distribute
 * the resulting executable under terms of your choice, provided
 * that you also meet, for each linked independent module, the
 * terms and conditions of the license of that module. An
 * independent module is a module which is not derived from or
 * based on this software. If you modify this software, you may
 * extend this exception to your version of the software, but
 * you are not obligated to do so. If you do not wish to do so,
 * delete this exception statement from your version.
 *
 * Fabric3 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the
 * GNU General Public License along with Fabric3.
 * If not, see <http://www.gnu.org/licenses/>.
*/
package org.fabric3.management.rest.runtime;

import org.fabric3.management.rest.spi.ResourceHost;
import org.fabric3.spi.federation.MessageReceiver;

/**
 * Listens to {@link ReplicationEnvelope}s sent when a resource request is broadcast in a zone and dispatches the associated request to the managed
 * resource hosted on the runtime.
 *
 * @version $Rev: 10013 $ $Date: 2011-02-19 14:17:58 +0000 (Sat, 19 Feb 2011) $
 */
public class ResourceReplicationHandler implements MessageReceiver {
    private ResourceHost resourceHost;
    private ManagementMonitor monitor;

    public ResourceReplicationHandler(ResourceHost resourceHost, ManagementMonitor monitor) {
        this.resourceHost = resourceHost;
        this.monitor = monitor;
    }

    public void onMessage(Object event) {
        if (!(event instanceof ReplicationEnvelope)) {
            monitor.error("Unknown resource request replication type: " + event.getClass());
            return;
        }
        ReplicationEnvelope envelope = (ReplicationEnvelope) event;
        resourceHost.dispatch(envelope.getPath(), envelope.getVerb(), envelope.getParams());
    }
}
